diff -urN linuxppc_2_4_devel-prev/init/do_mounts.c linuxppc_2_4_devel-local/init/do_mounts.c
--- linuxppc_2_4_devel-prev/init/do_mounts.c	2003-01-11 13:25:47.000000000 +0000
+++ linuxppc_2_4_devel-local/init/do_mounts.c	2003-01-11 13:26:06.000000000 +0000
@@ -447,7 +447,7 @@
 }
 __setup("ramdisk_start=", ramdisk_start_setup);
 
-static int __init crd_load(int in_fd, int out_fd);
+static int __init crd_load(int in_fd, int out_fd, char *from);
 
 /*
  * This routine tries to find a RAM disk image to load, and returns the
@@ -571,7 +571,7 @@
 
 	if (nblocks == 0) {
 #ifdef BUILD_CRAMDISK
-		if (crd_load(in_fd, out_fd) == 0)
+		if (crd_load(in_fd, out_fd, from) == 0)
 			goto successful_load;
 #else
 		printk(KERN_NOTICE
@@ -920,6 +920,7 @@
 static int exit_code;
 static long bytes_out;
 static int crd_infd, crd_outfd;
+static char *crd_from;
 
 #define get_byte()  (inptr < insize ? inbuf[inptr++] : fill_inbuf())
 		
@@ -968,11 +969,43 @@
  */
 static int __init fill_inbuf(void)
 {
+	static int cur_disk = 1;
+	static unsigned short rotate = 0;
+#if !defined(CONFIG_ARCH_S390) && !defined(CONFIG_PPC_ISERIES)
+	static char rotator[4] = { '|' , '/' , '-' , '\\' };
+#endif
+
 	if (exit_code) return -1;
 	
 	insize = read(crd_infd, inbuf, INBUFSIZ);
-	if (insize == 0) return -1;
+	if (insize == 0) {
+		/* finished this floppy, proceed to the next */
+		printk("done disk #%d.\n", cur_disk);
+		rotate = 0;
+		if (close(crd_infd)) {
+			printk(KERN_ERR "Error closing the disk.\n");
+			return -1;
+		}
+		change_floppy("disk #%d", ++cur_disk);
+		crd_infd = open(crd_from, O_RDONLY, 0);
+		if (crd_infd < 0)  {
+			printk(KERN_ERR "Error opening the disk.\n");
+			return -1;
+		}
+		printk(KERN_NOTICE "Loading disk #%d... ", cur_disk);
 
+		insize = read(crd_infd, inbuf, INBUFSIZ);
+	}
+	if (insize == -1) {
+		printk("\n" KERN_ERR "Error reading the disk.\n");
+		return -1;
+	}
+
+#if !defined(CONFIG_ARCH_S390) && !defined(CONFIG_PPC_ISERIES)
+	if (!(rotate % 8))
+		printk("%c\b", rotator[(rotate >> 3) & 0x3]);
+	rotate++;
+#endif
 	inptr = 1;
 
 	return inbuf[0];
@@ -1005,7 +1038,7 @@
 	exit_code = 1;
 }
 
-static int __init crd_load(int in_fd, int out_fd)
+static int __init crd_load(int in_fd, int out_fd, char *from)
 {
 	int result;
 
@@ -1018,6 +1051,7 @@
 
 	crd_infd = in_fd;
 	crd_outfd = out_fd;
+	crd_from = from;
 	inbuf = kmalloc(INBUFSIZ, GFP_KERNEL);
 	if (inbuf == 0) {
 		printk(KERN_ERR "RAMDISK: Couldn't allocate gzip buffer\n");
@@ -1029,8 +1063,13 @@
 		kfree(inbuf);
 		return -1;
 	}
+
+	printk(KERN_NOTICE "RAMDISK: Loading compressed image into ram disk... ");
 	makecrc();
 	result = gunzip();
+	if (!result)
+		printk("done.\n");
+
 	kfree(inbuf);
 	kfree(window);
 	return result;
